# Report-of-Monaco
To install the function you need to execute a command:

"pip install Report-of-Monaco-Second"

This function read data from 2 files, order racers by time and print report that shows the top 15 racers and the rest after underline.

To define unique characters, run python and import the package:
"from Functions import main"
"main.main()"